# Duel

Team Name: Python Buds 
Team Members: Alexis Dougherty, Aaron Gonzalez, Zachary Stanford, Grace Wilcox, and Joshua Zimmerman
Github: https://github.com/AlexisDougherty13/Duel

## How to run:
After pip install duel, open the XLaunch application, then type 'python3 -m duel' into the console to run the game.
You might need to be in the root directory to run the game.

## PyPi Package Name
The PyPi Package Name is duel

## How to Play
### Objective
Maneuver sword and position in order to avoid your opponent's attacks. Match your opponent's guard and deflect incoming strikes. Attack the opponent in low, mid, and high guarding positions.  Move your sword into your opponent's from above or below to disarm, but be quick for they can reclaim their fallen sword by ducking near it. If you strike where your opponent is not prepared, you will slay them. The first duelist to reach the opponent's flag on the opposite side of the field claims victory!
### Controls
  * Player 1
    * A/D - Left/Right Movement
    * W/S - Guard Up/Down
    * S(while in low guard) - Duck
    * Space - Jump
    * F - Sword Thrust
  * Player 2
    * Left/Right Arrow - Left/Right Movement
    * Up/Down Arrow - Guard Up/Down
    * Down Arrow(while in low guard) - Duck
    * Right Shift - Jump
    * Right Ctrl - Sword Thrust
